@@ -1,6 +1,7 @@
 # coding:utf8
 import hashlib
 import json
+import os.path
 import sys
 import uuid
 from datetime import datetime
@@ -33,14 +34,28 @@ def get_time():
     return datetime.now().strftime("%Y-%m-%d %X")
 
 
-def read_excel(path, sheet_index=0, is_value=True):
+def read_excel(path, sheet_index=0, is_value=True, is_replace=True, is_ffill=False):
+    """
+    读取Excel
+    :param path:
+    :param sheet_index:
+    :param is_value:
+    :param is_replace:
+    :param is_ffill: 单元格为空值（NaN，非空字符串）时，填充上一行的值，适用于合并单元格的情况。
+    :return:
+    """
     df = pd.read_excel(path, sheet_name=sheet_index)
+    if is_ffill:
+        df = df.ffill()
+
     # nan替换为空字符串
-    df1 = df.replace(np.nan, '', regex=True)
+    if is_replace:
+        df = df.replace(np.nan, '', regex=True)
+
     if is_value:
-        return df1.values
+        return df.values
     else:
-        return df1
+        return df
 
 
 def write_excel(path, result_list=[], columns=[], df=None, sheet_index=0):
@@ -66,6 +81,17 @@ def df_to_sql(path_df, table, engine, is_df=False):
     df.to_sql(table, engine, if_exists='append', index=False)
 
 
+def get_extension(path):
+    """
+    获取扩展名（小写）
+    :param path:
+    :return:
+    """
+    if not os.path.exists(path):
+        raise ValueError('file not exists!')
+    return os.path.splitext(path)[-1].lower()
+
+
 def read_txt(path):
     data_list = []
     with open(path, encoding='utf8') as f:
